==> mediawiki_1.39.12.orig.tar.gz: mediawiki-1.39.12/includes/libs/filebackend/fileophandle/SwiftFileOpHandle.php <==
<?php
/**
 * OpenStack Swift based file backend.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * http://www.gnu.org/copyleft/gpl.html
 *
 * @file
 * @ingroup FileBackend
 * @author Russ Nelson
 */

class SwiftFileOpHandle extends FileBackendStoreOpHandle {
	/** @var array[] List of HTTP request maps for MultiHttpClient */
	public $httpOp;
	/** @var Closure Function to run after each HTTP request finishes */
	public $callback;

	/** @var int Class CONTINUE_* constant */
	public $state = self::CONTINUE_IF_OK;

	/** @var int Continue with the next requests stages if no errors occurred */
	public const CONTINUE_IF_OK = 0;
	/** @var int Cancel the next requests stages */
	public const CONTINUE_NO = 1;

	/**
	 * Construct a handle to be use with SwiftFileOpHandle::doExecuteOpHandlesInternal()
	 *
	 * The callback returns a class CONTINUE_* constant and takes the following parameters:
	 *   - An HTTP request map array with 'response' filled
	 *   - A StatusValue instance to be updated as needed
	 *
	 * @param SwiftFileBackend $backend
	 * @param Closure $callback
	 * @param array $httpOp MultiHttpClient op
	 */
	public function __construct( SwiftFileBackend $backend, Closure $callback, array $httpOp ) {
		$this->backend = $backend;
		$this->callback = $callback;
		$this->httpOp = $httpOp;
	}
}

==> mediawiki-1.45.1.tar.gz: mediawiki-1.45.1/includes/libs/filebackend/fileophandle/SwiftFileOpHandle.php <==
<?php
/**
 * OpenStack Swift based file backend.
 *
 * @license GPL-2.0-or-later
 * @file
 * @ingroup FileBackend
 * @author Russ Nelson
 */

namespace Wikimedia\FileBackend\FileOpHandle;

use Closure;
use Wikimedia\FileBackend\SwiftFileBackend;

class SwiftFileOpHandle extends FileBackendStoreOpHandle {
	/** @var array[] List of HTTP request maps for SwiftFileBackend::requestWithAuth */
	public $httpOp;
	/** @var Closure Function to run after each HTTP request finishes */
	public $callback;

	/** @var int Class CONTINUE_* constant */
	public $state = self::CONTINUE_IF_OK;

	/** @var int Continue with the next requests stages if no errors occurred */
	public const CONTINUE_IF_OK = 0;
	/** @var int Cancel the next requests stages */
	public const CONTINUE_NO = 1;

	/**
	 * Construct a handle to be use with SwiftFileOpHandle::doExecuteOpHandlesInternal()
	 *
	 * The callback returns a class CONTINUE_* constant and takes the following parameters:
	 *   - An HTTP request map array with 'response' filled
	 *   - A StatusValue instance to be updated as needed
	 *
	 * @param SwiftFileBackend $backend
	 * @param Closure $callback
	 * @param array $httpOp Request to send via SwiftFileBackend::requestWithAuth()
	 */
	public function __construct( SwiftFileBackend $backend, Closure $callback, array $httpOp ) {
		$this->backend = $backend;
		$this->callback = $callback;
		$this->httpOp = $httpOp;
	}
}

/** @deprecated class alias since 1.43 */
class_alias( SwiftFileOpHandle::class, 'SwiftFileOpHandle' );
